|PyPI| |Travis| |DOI|

.. |PyPI| image:: https://img.shields.io/pypi/v/oceans.svg
   :target: https://pypi.org/project/oceans/
   :alt: PyPI Package

.. |Travis| image:: https://travis-ci.org/pyoceans/python-oceans.svg?branch=master
   :target: https://travis-ci.org/pyoceans/python-oceans
   :alt: Travis Build Status

.. |DOI| image:: https://zenodo.org/badge/11956337.svg
   :target: https://zenodo.org/badge/latestdoi/11956337
   :alt: DOI

python-oceans
=============

Misc helper functions for ocean sciences.

Most of the functions here are Python versions of some common MatlabTM functions.
They are untested and probably buggy. Use with caution!
